# pip install docxcompose python-docx

import os
import sys
from pathlib import Path

from docx import Document
from docx.shared import Inches
from docxcompose.composer import Composer
from docx import Document as Document_compose


def create_master_docx(path: Path):
    """
    Создаем и сохраняем пустой документ.
    """
    document = Document()
    section = document.sections[-1]
    section.top_margin = Inches(0.8)
    section.bottom_margin = Inches(0.8)
    section.left_margin = Inches(1.2)
    section.right_margin = Inches(1.2)
    document.save(path)


def merge_docx(path_master: Path, files: list):
    """
    Открываем файл в который будем объединять все остальные.
    Создаем композитора. Запускаем цикл по списку файлов.
    Добавляем в композитор содержимое каждого файла из списка.
    Сохраняем итоговый документ.
    """
    number_of_sections = len(files)
    master = Document_compose(path_master)
    composer = Composer(master)
    for i in range(0, number_of_sections):
        doc_temp = Document_compose(files[i])
        composer.append(doc_temp)
    composer.save(path_master)


def main():
    """
    Запрашиваем имя для объединенного файла.
    Запрашиваем путь к директории с файлами для объединения.
    Проверяем существование директории и является ли переданный путь путем к директории.
    Получаем список файлов в директории, формируем список файлов с полным путем к ним.
    Создаем новый документ.
    Объединяем документы из директории.
    """
    path = Path.cwd() / f'{input("Введите имя для объединенного файла: ")}.docx'
    merge_dir = input("Введите путь к директории с документами для объединения: ")
    if not Path(merge_dir).exists() or not Path(merge_dir).is_dir():
        print("Директории не существует")
        sys.exit(0)
    files = [Path(merge_dir) / x for x in os.listdir(merge_dir) if Path(x).suffix == ".docx"]
    if files:
        create_master_docx(path)
        merge_docx(path, files)
        print(f"Объединение завершено. Объединенный файл -> {path}")
    else:
        print("Файлов для объединения не найдено")


if __name__ == "__main__":
    main()
